[Mulgara-svn] r1746 - trunk/src/jar/tuples/java/org/mulgara/store/tuples

pag at mulgara.org pag at mulgara.org
Mon Jun 29 22:06:42 UTC 2009


Author: pag
Date: 2009-06-29 15:06:41 -0700 (Mon, 29 Jun 2009)
New Revision: 1746

Modified:
   trunk/src/jar/tuples/java/org/mulgara/store/tuples/TuplesOperations.java
Log:
Adjustment of fudge-factor used for probabilistic weighting of row counts

Modified: trunk/src/jar/tuples/java/org/mulgara/store/tuples/TuplesOperations.java
===================================================================
--- trunk/src/jar/tuples/java/org/mulgara/store/tuples/TuplesOperations.java	2009-06-29 22:04:10 UTC (rev 1745)
+++ trunk/src/jar/tuples/java/org/mulgara/store/tuples/TuplesOperations.java	2009-06-29 22:06:41 UTC (rev 1746)
@@ -661,14 +661,14 @@
       // This fails to consider the effect on performance of worst case so we
       // incorporate weighted terms to allow for possible skew on each column.
       // We assume a reducing probability of compounded failure so weight each
       // term by 10**term (0-indexed), this is a fudge factor that needs proper
       // analysis.
       double weightedRowCount = 0.0;
       for (int weight = 0; weight < numLeftBindings + 1; weight++) {
         double term = vars.length > 0
                         ? Math.pow(tuples.getRowUpperBound(), (double)(vars.length - (numLeftBindings - weight)) / vars.length)
                         : tuples.getRowUpperBound();
-        weightedRowCount += term / Math.pow(10.0, weight);
+        weightedRowCount += term / Math.pow(100.0, weight);
       }
 
       if (logger.isDebugEnabled()) {
@@ -661,14 +661,14 @@
       // incorporate weighted terms to allow for possible skew on each column.
       // We assume a reducing probability of compounded failure so weight each
-      // term by 10**term (0-indexed), this is a fudge factor that needs proper
+      // term by 100**term (0-indexed), this is a fudge factor that needs proper
       // analysis.
       double weightedRowCount = 0.0;




More information about the Mulgara-svn mailing list